<div class="columns" role="navigation" aria-label="Secondary">
  <div class="column">
    <ul class="nav-spaced">
      <li><a href="{{ config_url('contact') }}">Contact</a></li>
      <li><a href="{{ config_url('twitter') }}">Find us on Twitter</a></li>
    </ul>
  </div>
  <div class="column">
    <ul class="nav-spaced">
      <li><a href="{{ config_url('blog') }}">Blog - the latest news</a></li>
      <li><a href="{{ config_url('wiki') }}">Wiki - project documentation</a></li>
    </ul>
  </div>
  <div class="column">
    <ul class="nav-spaced">
      <li><a href="{{ config_url('accessibility') }}">Web Accessibility Help</a></li>
      <li><a href="{{ config_url('help') }}">Help with using arXiv</a></li>
    </ul>
  </div>
</div>
