// Overrides

header .columns .column
  padding-bottom: 0

content a
  border-bottom: 1px solid transparent
  &:hover
    border-bottom: 1px dotted $blue

.help,
.is-small
  font-family: $family-smalltext
